@@ -126,7 +126,6 @@ class MultiThreadingManager(object):
     def __init__(self, create_connection, segment_threads=10,
                  object_dd_threads=10, object_uu_threads=10,
                  container_threads=10):
-
         """
         :param segment_threads: The number of threads allocated to segment
                                 uploads
@@ -169,6 +168,12 @@ class ConnectionThreadPoolExecutor(ThreadPoolExecutor):
     We will only create as many connections as are required concurrently.
     """
     def __init__(self, create_connection, max_workers):
+        """
+        Initializes a new ThreadPoolExecutor instance.
+
+        :param create_connection: callable to use to create new connections
+        :param max_workers: the maximum number of threads that can be used
+        """
         self._connections = PriorityQueue()
         self._create_connection = create_connection
         for p in range(0, max_workers):
@@ -176,6 +181,14 @@ class ConnectionThreadPoolExecutor(ThreadPoolExecutor):
         super(ConnectionThreadPoolExecutor, self).__init__(max_workers)
 
     def submit(self, fn, *args, **kwargs):
+        """
+        Schedules the callable, `fn`, to be executed
+
+        :param fn: the callable to be invoked
+        :param args: the positional arguments for the callable
+        :param kwargs: the keyword arguments for the callable
+        :returns: a Future object representing the execution of the callable
+        """
         def conn_fn():
             priority = None
             conn = None
